/*--------------------------------------------------------------------------*/
/**
 * TrimPath Template. Release 1.0.38.
 * Copyright (C) 2004, 2005 Metaha.
 * 
 * TrimPath Template is licensed under the GNU General Public License
 * and the Apache License, Version 2.0, as follows:
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; without even the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*--------------------------------------------------------------------------*/ 
var $jj = jQuery.noConflict();
var TrimPath;

// TODO: Debugging mode vs stop-on-error mode - runtime flag.
// TODO: Handle || (or) characters and backslashes.
// TODO: Add more modifiers.

(function() {               // Using a closure to keep global namespace clean.
    if (TrimPath == null)
        TrimPath = new Object();
    if (TrimPath.evalEx == null)
        TrimPath.evalEx = function(src) { return eval(src); };

    var UNDEFINED;
    if (Array.prototype.pop == null)  // IE 5.x fix from Igor Poteryaev.
        Array.prototype.pop = function() {
            if (this.length === 0) {return UNDEFINED;}
            return this[--this.length];
        };
    if (Array.prototype.push == null) // IE 5.x fix from Igor Poteryaev.
        Array.prototype.push = function() {
            for (var i = 0; i < arguments.length; ++i) {this[this.length] = arguments[i];}
            return this.length;
        };

    TrimPath.parseTemplate = function(tmplContent, optTmplName, optEtc) {
        if (optEtc == null)
            optEtc = TrimPath.parseTemplate_etc;
        var funcSrc = parse(tmplContent, optTmplName, optEtc);
        var func = TrimPath.evalEx(funcSrc, optTmplName, 1);
        if (func != null)
            return new optEtc.Template(optTmplName, tmplContent, funcSrc, func, optEtc);
        return null;
    }
    
    try {
        String.prototype.process = function(context, optFlags) {
            var template = TrimPath.parseTemplate(this, null);
            if (template != null)
                return template.process(context, optFlags);
            return this;
        }
    } catch (e) { // Swallow exception, such as when String.prototype is sealed.
    }
    
    TrimPath.parseTemplate_etc = {};            // Exposed for extensibility.
    TrimPath.parseTemplate_etc.statementTag = "forelse|for|if|elseif|else|var|macro";
    TrimPath.parseTemplate_etc.statementDef = { // Lookup table for statement tags.
        "if"     : { delta:  1, prefix: "if (", suffix: ") {", paramMin: 1 },
        "else"   : { delta:  0, prefix: "} else {" },
        "elseif" : { delta:  0, prefix: "} else if (", suffix: ") {", paramDefault: "true" },
        "/if"    : { delta: -1, prefix: "}" },
        "for"    : { delta:  1, paramMin: 3, 
                     prefixFunc : function(stmtParts, state, tmplName, etc) {
                        if (stmtParts[2] != "in")
                            throw new etc.ParseError(tmplName, state.line, "bad for loop statement: " + stmtParts.join(' '));
                        var iterVar = stmtParts[1];
                        var listVar = "__LIST__" + iterVar;
                        return [ "var ", listVar, " = ", stmtParts[3], ";",
                             // Fix from Ross Shaull for hash looping, make sure that we have an array of loop lengths to treat like a stack.
                             "var __LENGTH_STACK__;",
                             "if (typeof(__LENGTH_STACK__) == 'undefined' || !__LENGTH_STACK__.length) __LENGTH_STACK__ = new Array();", 
                             "__LENGTH_STACK__[__LENGTH_STACK__.length] = 0;", // Push a new for-loop onto the stack of loop lengths.
                             "if ((", listVar, ") != null) { ",
                             "var ", iterVar, "_ct = 0;",       // iterVar_ct variable, added by B. Bittman     
                             "for (var ", iterVar, "_index in ", listVar, ") { ",
                             iterVar, "_ct++;",
                             "if (typeof(", listVar, "[", iterVar, "_index]) == 'function') {continue;}", // IE 5.x fix from Igor Poteryaev.
                             "__LENGTH_STACK__[__LENGTH_STACK__.length - 1]++;",
                             "var ", iterVar, " = ", listVar, "[", iterVar, "_index];" ].join("");
                     } },
        "forelse" : { delta:  0, prefix: "} } if (__LENGTH_STACK__[__LENGTH_STACK__.length - 1] == 0) { if (", suffix: ") {", paramDefault: "true" },
        "/for"    : { delta: -1, prefix: "} }; delete __LENGTH_STACK__[__LENGTH_STACK__.length - 1];" }, // Remove the just-finished for-loop from the stack of loop lengths.
        "var"     : { delta:  0, prefix: "var ", suffix: ";" },
        "macro"   : { delta:  1, 
                      prefixFunc : function(stmtParts, state, tmplName, etc) {
                          var macroName = stmtParts[1].split('(')[0];
                          return [ "var ", macroName, " = function", 
                                   stmtParts.slice(1).join(' ').substring(macroName.length),
                                   "{ var _OUT_arr = []; var _OUT = { write: function(m) { if (m) _OUT_arr.push(m); } }; " ].join('');
                     } }, 
        "/macro"  : { delta: -1, prefix: " return _OUT_arr.join(''); };" }
    }
    TrimPath.parseTemplate_etc.modifierDef = {
        "eat"        : function(v)    { return ""; },
        "escape"     : function(s)    { return String(s).replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;"); },
        "capitalize" : function(s)    { return String(s).toUpperCase(); },
        "default"    : function(s, d) { return s != null ? s : d; }
    }
    TrimPath.parseTemplate_etc.modifierDef.h = TrimPath.parseTemplate_etc.modifierDef.escape;

    TrimPath.parseTemplate_etc.Template = function(tmplName, tmplContent, funcSrc, func, etc) {
        this.process = function(context, flags) {
            if (context == null)
                context = {};
            if (context._MODIFIERS == null)
                context._MODIFIERS = {};
            if (context.defined == null)
                context.defined = function(str) { return (context[str] != undefined); };
            for (var k in etc.modifierDef) {
                if (context._MODIFIERS[k] == null)
                    context._MODIFIERS[k] = etc.modifierDef[k];
            }
            if (flags == null)
                flags = {};
            var resultArr = [];
            var resultOut = { write: function(m) { resultArr.push(m); } };
            try {
                func(resultOut, context, flags);
            } catch (e) {
                if (flags.throwExceptions == true)
                    throw e;
                var result = new String(resultArr.join("") + "[ERROR: " + e.toString() + (e.message ? '; ' + e.message : '') + "]");
                result["exception"] = e;
                return result;
            }
            return resultArr.join("");
        }
        this.name       = tmplName;
        this.source     = tmplContent; 
        this.sourceFunc = funcSrc;
        this.toString   = function() { return "TrimPath.Template [" + tmplName + "]"; }
    }
    TrimPath.parseTemplate_etc.ParseError = function(name, line, message) {
        this.name    = name;
        this.line    = line;
        this.message = message;
    }
    TrimPath.parseTemplate_etc.ParseError.prototype.toString = function() { 
        return ("TrimPath template ParseError in " + this.name + ": line " + this.line + ", " + this.message);
    }
    
    var parse = function(body, tmplName, etc) {
        body = cleanWhiteSpace(body);
        var funcText = [ "var TrimPath_Template_TEMP = function(_OUT, _CONTEXT, _FLAGS) { with (_CONTEXT) {" ];
        var state    = { stack: [], line: 1 };                              // TODO: Fix line number counting.
        var endStmtPrev = -1;
        while (endStmtPrev + 1 < body.length) {
            var begStmt = endStmtPrev;
            // Scan until we find some statement markup.
            begStmt = body.indexOf("{", begStmt + 1);
            while (begStmt >= 0) {
                var endStmt = body.indexOf('}', begStmt + 1);
                var stmt = body.substring(begStmt, endStmt);
                var blockrx = stmt.match(/^\{(cdata|minify|eval)/); // From B. Bittman, minify/eval/cdata implementation.
                if (blockrx) {
                    var blockType = blockrx[1]; 
                    var blockMarkerBeg = begStmt + blockType.length + 1;
                    var blockMarkerEnd = body.indexOf('}', blockMarkerBeg);
                    if (blockMarkerEnd >= 0) {
                        var blockMarker;
                        if( blockMarkerEnd - blockMarkerBeg <= 0 ) {
                            blockMarker = "{/" + blockType + "}";
                        } else {
                            blockMarker = body.substring(blockMarkerBeg + 1, blockMarkerEnd);
                        }                        
                        
                        var blockEnd = body.indexOf(blockMarker, blockMarkerEnd + 1);
                        if (blockEnd >= 0) {                            
                            emitSectionText(body.substring(endStmtPrev + 1, begStmt), funcText);
                            
                            var blockText = body.substring(blockMarkerEnd + 1, blockEnd);
                            if (blockType == 'cdata') {
                                emitText(blockText, funcText);
                            } else if (blockType == 'minify') {
                                emitText(scrubWhiteSpace(blockText), funcText);
                            } else if (blockType == 'eval') {
                                if (blockText != null && blockText.length > 0) // From B. Bittman, eval should not execute until process().
                                    funcText.push('_OUT.write( (function() { ' + blockText + ' })() );');
                            }
                            begStmt = endStmtPrev = blockEnd + blockMarker.length - 1;
                        }
                    }                        
                } else if (body.charAt(begStmt - 1) != '$' &&               // Not an expression or backslashed,
                           body.charAt(begStmt - 1) != '\\') {              // so check if it is a statement tag.
                    var offset = (body.charAt(begStmt + 1) == '/' ? 2 : 1); // Close tags offset of 2 skips '/'.
                                                                            // 10 is larger than maximum statement tag length.
                    if (body.substring(begStmt + offset, begStmt + 10 + offset).search(TrimPath.parseTemplate_etc.statementTag) == 0) 
                        break;                                              // Found a match.
                }
                begStmt = body.indexOf("{", begStmt + 1);
            }
            if (begStmt < 0)                              // In "a{for}c", begStmt will be 1.
                break;
            var endStmt = body.indexOf("}", begStmt + 1); // In "a{for}c", endStmt will be 5.
            if (endStmt < 0)
                break;
            emitSectionText(body.substring(endStmtPrev + 1, begStmt), funcText);
            emitStatement(body.substring(begStmt, endStmt + 1), state, funcText, tmplName, etc);
            endStmtPrev = endStmt;
        }
        emitSectionText(body.substring(endStmtPrev + 1), funcText);
        if (state.stack.length != 0)
            throw new etc.ParseError(tmplName, state.line, "unclosed, unmatched statement(s): " + state.stack.join(","));
        funcText.push("}}; TrimPath_Template_TEMP");
        return funcText.join("");
    }
    
    var emitStatement = function(stmtStr, state, funcText, tmplName, etc) {
        var parts = stmtStr.slice(1, -1).split(' ');
        var stmt = etc.statementDef[parts[0]]; // Here, parts[0] == for/if/else/...
        if (stmt == null) {                    // Not a real statement.
            emitSectionText(stmtStr, funcText);
            return;
        }
        if (stmt.delta < 0) {
            if (state.stack.length <= 0)
                throw new etc.ParseError(tmplName, state.line, "close tag does not match any previous statement: " + stmtStr);
            state.stack.pop();
        } 
        if (stmt.delta > 0)
            state.stack.push(stmtStr);

        if (stmt.paramMin != null &&
            stmt.paramMin >= parts.length)
            throw new etc.ParseError(tmplName, state.line, "statement needs more parameters: " + stmtStr);
        if (stmt.prefixFunc != null)
            funcText.push(stmt.prefixFunc(parts, state, tmplName, etc));
        else 
            funcText.push(stmt.prefix);
        if (stmt.suffix != null) {
            if (parts.length <= 1) {
                if (stmt.paramDefault != null)
                    funcText.push(stmt.paramDefault);
            } else {
                for (var i = 1; i < parts.length; i++) {
                    if (i > 1)
                        funcText.push(' ');
                    funcText.push(parts[i]);
                }
            }
            funcText.push(stmt.suffix);
        }
    }

    var emitSectionText = function(text, funcText) {
        if (text.length <= 0)
            return;
        var nlPrefix = 0;               // Index to first non-newline in prefix.
        var nlSuffix = text.length - 1; // Index to first non-space/tab in suffix.
        while (nlPrefix < text.length && (text.charAt(nlPrefix) == '\n'))
            nlPrefix++;
        while (nlSuffix >= 0 && (text.charAt(nlSuffix) == ' ' || text.charAt(nlSuffix) == '\t'))
            nlSuffix--;
        if (nlSuffix < nlPrefix)
            nlSuffix = nlPrefix;
        if (nlPrefix > 0) {
            funcText.push('if (_FLAGS.keepWhitespace == true) _OUT.write("');
            var s = text.substring(0, nlPrefix).replace('\n', '\\n'); // A macro IE fix from BJessen.
            if (s.charAt(s.length - 1) == '\n')
            	s = s.substring(0, s.length - 1);
            funcText.push(s);
            funcText.push('");');
        }
        var lines = text.substring(nlPrefix, nlSuffix + 1).split('\n');
        for (var i = 0; i < lines.length; i++) {
            emitSectionTextLine(lines[i], funcText);
            if (i < lines.length - 1)
                funcText.push('_OUT.write("\\n");\n');
        }
        if (nlSuffix + 1 < text.length) {
            funcText.push('if (_FLAGS.keepWhitespace == true) _OUT.write("');
            var s = text.substring(nlSuffix + 1).replace('\n', '\\n');
            if (s.charAt(s.length - 1) == '\n')
            	s = s.substring(0, s.length - 1);
            funcText.push(s);
            funcText.push('");');
        }
    }
    
    var emitSectionTextLine = function(line, funcText) {
        var endMarkPrev = '}';
        var endExprPrev = -1;
        while (endExprPrev + endMarkPrev.length < line.length) {
            var begMark = "${", endMark = "}";
            var begExpr = line.indexOf(begMark, endExprPrev + endMarkPrev.length); // In "a${b}c", begExpr == 1
            if (begExpr < 0)
                break;
            if (line.charAt(begExpr + 2) == '%') {
                begMark = "${%";
                endMark = "%}";
            }
            var endExpr = line.indexOf(endMark, begExpr + begMark.length);         // In "a${b}c", endExpr == 4;
            if (endExpr < 0)
                break;
            emitText(line.substring(endExprPrev + endMarkPrev.length, begExpr), funcText);                
            // Example: exprs == 'firstName|default:"John Doe"|capitalize'.split('|')
            var exprArr = line.substring(begExpr + begMark.length, endExpr).replace(/\|\|/g, "#@@#").split('|');
            for (var k in exprArr) {
                if (exprArr[k].replace) // IE 5.x fix from Igor Poteryaev.
                    exprArr[k] = exprArr[k].replace(/#@@#/g, '||');
            }
            funcText.push('_OUT.write(');
            emitExpression(exprArr, exprArr.length - 1, funcText); 
            funcText.push(');');
            endExprPrev = endExpr;
            endMarkPrev = endMark;
        }
        emitText(line.substring(endExprPrev + endMarkPrev.length), funcText); 
    }
    
    var emitText = function(text, funcText) {
        if (text == null ||
            text.length <= 0)
            return;
        text = text.replace(/\\/g, '\\\\');
        text = text.replace(/\n/g, '\\n');
        text = text.replace(/"/g,  '\\"');
        funcText.push('_OUT.write("');
        funcText.push(text);
        funcText.push('");');
    }
    
    var emitExpression = function(exprArr, index, funcText) {
        // Ex: foo|a:x|b:y1,y2|c:z1,z2 is emitted as c(b(a(foo,x),y1,y2),z1,z2)
        var expr = exprArr[index]; // Ex: exprArr == [firstName,capitalize,default:"John Doe"]
        if (index <= 0) {          // Ex: expr    == 'default:"John Doe"'
            funcText.push(expr);
            return;
        }
        var parts = expr.split(':');
        funcText.push('_MODIFIERS["');
        funcText.push(parts[0]); // The parts[0] is a modifier function name, like capitalize.
        funcText.push('"](');
        emitExpression(exprArr, index - 1, funcText);
        if (parts.length > 1) {
            funcText.push(',');
            funcText.push(parts[1]);
        }
        funcText.push(')');
    }

    var cleanWhiteSpace = function(result) {
        result = result.replace(/\t/g,   "    ");
        result = result.replace(/\r\n/g, "\n");
        result = result.replace(/\r/g,   "\n");
        result = result.replace(/^(\s*\S*(\s+\S+)*)\s*$/, '$1'); // Right trim by Igor Poteryaev.
        return result;
    }

    var scrubWhiteSpace = function(result) {
        result = result.replace(/^\s+/g,   "");
        result = result.replace(/\s+$/g,   "");
        result = result.replace(/\s+/g,   " ");
        result = result.replace(/^(\s*\S*(\s+\S+)*)\s*$/, '$1'); // Right trim by Igor Poteryaev.
        return result;
    }

    // The DOM helper functions depend on DOM/DHTML, so they only work in a browser.
    // However, these are not considered core to the engine.
    //
    TrimPath.parseDOMTemplate = function(elementId, optDocument, optEtc) {
        if (optDocument == null)
            optDocument = document;
        var element = optDocument.getElementById(elementId);
        var content = element.value;     // Like textarea.value.
        if (content == null)
            content = element.innerHTML; // Like textarea.innerHTML.
        content = content.replace(/&lt;/g, "<").replace(/&gt;/g, ">");
        return TrimPath.parseTemplate(content, elementId, optEtc);
    }

    TrimPath.processDOMTemplate = function(elementId, context, optFlags, optDocument, optEtc) {
        return TrimPath.parseDOMTemplate(elementId, optDocument, optEtc).process(context, optFlags);
    }
}) ();


/**
*
*  UTF-8 data encode / decode
*  http://www.webtoolkit.info/
*
**/

var Utf8 = {

    // public method for url encoding
    encode : function (string) {
        string = string.replace(/\r\n/g,"\n");
        var utftext = "";

        for (var n = 0; n < string.length; n++) {

            var c = string.charCodeAt(n);

            if (c < 128) {
                utftext += String.fromCharCode(c);
            }
            else if((c > 127) && (c < 2048)) {
                utftext += String.fromCharCode((c >> 6) | 192);
                utftext += String.fromCharCode((c & 63) | 128);
            }
            else {
                utftext += String.fromCharCode((c >> 12) | 224);
                utftext += String.fromCharCode(((c >> 6) & 63) | 128);
                utftext += String.fromCharCode((c & 63) | 128);
            }

        }

        return utftext;
    },

    // public method for url decoding
    decode : function (utftext) {
        var string = "";
        var i = 0;
        var c = c1 = c2 = 0;

        while ( i < utftext.length ) {

            c = utftext.charCodeAt(i);

            if (c < 128) {
                string += String.fromCharCode(c);
                i++;
            }
            else if((c > 191) && (c < 224)) {
                c2 = utftext.charCodeAt(i+1);
                string += String.fromCharCode(((c & 31) << 6) | (c2 & 63));
                i += 2;
            }
            else {
                c2 = utftext.charCodeAt(i+1);
                c3 = utftext.charCodeAt(i+2);
                string += String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
                i += 3;
            }

        }

        return string;
    }

}


/*--------------------------------------------------------------------------*/
/*  Modello dati UGC API javascript
 *  (c) 2006 Elemdia S.p.A.
/*--------------------------------------------------------------------------*/
/**
 *
 */
var mesi = [
 "gennaio",
 "febbraio",
 "marzo",
 "aprile",
 "maggio",
 "giugno",
 "luglio",
 "agosto",
 "settembre",
 "ottobre",
 "novembre",
 "dicembre"
];
 
var mm_on = false;
var voti_on = false;
 
function Post(titolo, autore, data, testo, numOfChilds, attachs, tags, id, idpadre, idevento, tot_voti, votanti, voti_si, voti_no) {
	this.oddEven=0;
	this.titolo = titolo;
	this.autore = autore;
	this.utcData = data;
	var darr = data.match(/\d+/g);
	if (darr) {
		this.data = darr[2]+" "+mesi[darr[1]-1]+" "+darr[0]+" alle "+darr[3]+":"+darr[4];
	} else {
		this.data = "&nbsp;";
	}
	//this.testo = Utf8.decode(testo);
	this.testo = testo;
	if (testo.length>300)
		this.minitesto = testo.substring(0,300)+"...";
	else 
		this.minitesto = testo;
	this.numOfChilds = numOfChilds;
	this.attachs = attachs;
	this.tags = tags;
	this.id = id;
	this.idpadre = idpadre;
	this.idevento = idevento;
	this.tot_voti = tot_voti;
	this.votanti = votanti;
	this.voti_si = voti_si;
	this.voti_no = voti_no;
	if (votanti>0) {		
		this.media = Math.round(tot_voti/votanti*100)/100;
		if (this.media > 5) 
			this.media=5;
	}
	else 
		this.media = 0;
	this.printAbstract = 0;
	// controlla alcune condizioni di stato del thread
	mm_on |= (attachs.length>0);
	voti_on |= (votanti>0);
}

/**
 *
 */
function Attach(url, tipo, size, thumb) {
	this.url = serverStream+url;
	this.tipo = tipo;
	this.size = size;
	this.thumb = serverStream+thumb;
	/*if (tipo.indexOf("image")>=0)
	{
		var sep = url.lastIndexOf("/");
		this.thumb = url.substring(0,sep)+"/thumb"+url.substring(sep);
	}*/
}




// Funzioni di ordinamento
var sortMethod = sortByDate;
var sortMethodOld = "-";
var sortOrder = 1;

function sortByDate(a, b)
{
	if (a.utcData == b.utcData) return 0;
	return sortOrder*((a.utcData > b.utcData) ? -1 : 1);
}

function sortByComments(a, b)
{
	return sortOrder*(b.numOfChilds - a.numOfChilds);
}

function sortByVote(a, b)
{
	return sortOrder*(b.votanti - a.votanti);
}

function sortByMeanVote(a, b)
{
	if (a.media == b.media) {
		return sortByVote(a,b);
	}
	return sortOrder*(b.media - a.media);
}
function sortByTitle(a, b)
{
	if (a.titolo == b.titolo) return 0;
	return sortOrder*((a.titolo < b.titolo) ? -1 : 1);
}

function setSortMethod(m)
{
	if (m != sortMethodOld)
	{		
		sortOrder = 1;
		sortMethodOld = m;
	} 
	else 
		sortOrder *= -1;
	
	switch (m){
		case "date": {
			sortMethod = sortByDate;
			break;
		}

		case "mean_vote": {
			sortMethod = sortByMeanVote;
			break;
		}

		case "votes": {
			sortMethod = sortByVote;
			break;
		}

		case "comments": {
			sortMethod = sortByComments;
			break;
		}

		case "title": {
			sortMethod = sortByTitle;
			break;
		}

		default : {
			sortMethod = sortByDate;
		}
	}
}

function printPostsNum(ncommenti)
{
	if (self['ugc_countTemplate'])
	{
		var tId = $jj("div[id="+ugc_countTemplate.targetId+"]");
		if (tId) {
			var tpl = ugc_countTemplate.template;
			var tplObj = TrimPath.parseTemplate(tpl);
			var html = tpl.process({"ncommenti":ncommenti});
			tId.innerHTML = html;
		}
	}
}


function controllaEspanso(){
	return (window.location.href.indexOf('#commentatutti')!=-1);
}

function goTo(url){
	window.location.href= url;
	//Il reload e' necessario per forzare la riesecuzione del js
	window.location.reload(true);
}

function printAbstractPostsPage(posts) {
  // DEBUG 	  	  alert ('608.Inizio record: '+begin);
	var posts_content = "";
	
	for (var i = 0; i < posts.length; i++) {
		id = posts[i]['id'];
		posts_content += printPostAbstract(posts[i],i%2);
	}
	if (document.getElementById("ugc_posts")) {
		document.getElementById("ugc_posts").innerHTML = posts_content;
	}
}
/**
 *
 */
 
 // dichiarazione variabili globali
var fathers = new Array();
var childs = new Array();
var childsNum = new Array();
var currentPage = 0;
var urlExplainedToGo="";

/**
 * Stampa i post effettuando la paginazione se post4page > 0 [post4page definita in jst-commenti.js]
 * Variante introdotta per gestire la stampa in base ai tag.
 */
function printPosts(posts) {

  if(!controllaEspanso() && !self['ugcTemplateDetail']){
	//template della lista di contenuti
	if (self['templateAbstract'])
		templateAbstractObj = TrimPath.parseTemplate(templateAbstract);
		var obj = Object();
		var newUrl = "";
		if(window.location.href.indexOf('#')!=-1){
			newUrl = window.location.href.substring(0, window.location.href.indexOf('#'));
		}else{
			newUrl = window.location.href;
		}
		//il passaggio nella url dentro la pagina causa problemi con le url encodate
		obj['url'] = newUrl+'#commentatutti';
		//allora usiamo in piu' una variabile d'appoggio
		urlExplainedToGo = newUrl+'#commentatutti';
		obj['count'] = ((self['threadMsgCount'] && threadMsgCount >=0) ? threadMsgCount : totPosts);

		document.getElementById("ugc-container").innerHTML = templateAbstractObj.process(obj);

		if(postAbstractToDisplay>0){
			fathersAndChilds(posts);
			fathers.sort(sortMethod);
			printAbstractPostsPage(fathers);
		}

  }else{

	if(controllaEspanso()){
		$jj("div[id=ugc_linkUpload]").before("<div id=\"commentatutti\" style=\"float: left;\"></div>");
	}

	/**
	* visualizzazione per tag
	* cfr. http://commenti.kataweb.it/commenti/scripts/primomaggio/jst-commenti-list-tag.js
	* printPostsTagged definita nel jst
	*/
	if (self['printPostsTagged'] && self['showContentsTagged'])
	{
		printPostsTagged(showContentsTagged);
	} else
	{
		/**
		* stampa standard di tutti i commenti (paginati)
		*/
		fathersAndChilds(posts);
		fathers.sort(sortMethod);
		currentPage = 0;
	
		// costruisce il tag cloud
		buildTagCloud(posts);
	
		printPostsNum(fathers.length);
	
		if (self['ugcTemplate']) {  
			if (post4page < 1) {
				printAllPosts(fathers);
			}
			else {
				// la paginazione avviene solo sui padri
				printPostsPage(fathers,0);
				// inserisco i numeri di pagina
				//numbersPages(fathers);
			}
		}
		
		//stampa il dettaglio se definite le variabili di dettaglio
		if (self['show_detail_target'] && self['show_detail_id'])
			showCommentDetail(show_detail_target,show_detail_id);						
	
		//se def. templateOrdina allora se mm_on o voti_on stampa i link di ordinamento
		if (self['templateOrdina'] && self['templateOrdina_target']) {
			if (mm_on || voti_on)
				$jj("div[id="+templateOrdina_target+"]").empty();
				$jj("div[id="+templateOrdina_target+"]").append(templateOrdina);
		}
		
		if (templateTagCloudObj && ugcTagCloud.tags.length>0) {
			$jj("div[id=ugc_tagcloud]").empty();
			//$jj("div[id=ugc_tagcloud]").append(templateTagCloudObj.process(ugcTagCloud));
		}
	}
	//devo costringere la pagina a puntare all'anchor
	if(controllaEspanso()){
		if(location.hash!="") location.href=location.hash;
	}
  }
}


if (!self['lastShownDetailId'])
	lastShownDetailId = null;
if (!self['lastShownDetailTarget'])
	lastShownDetailTarget = null;
	
function printPostDetail(target, id) {
	
	if (lastShownDetailId==id && lastShownDetailTarget==target)
	{
		return;
	}
	
	lastShownDetailId=id;
	lastShownDetailTarget=target;
	
	if (fathersHash[id]) {
		var post_content = "";

		//gestione separata di player, info e commenti figli
		if (self['ugcTemplatePlayer'] && self['ugcTemplateInfo'] && self['ugcTemplateComments']) {
						
			ugcTemplatePlayer.obj = TrimPath.parseTemplate(ugcTemplatePlayer.template);
			ugcTemplateInfo.obj = TrimPath.parseTemplate(ugcTemplateInfo.template);
			ugcTemplateComments.obj = TrimPath.parseTemplate(ugcTemplateComments.template);
			
			ugcTemplatePlayer.html = ugcTemplatePlayer.obj.process(fathersHash[id]);
			ugcTemplateInfo.html = ugcTemplateInfo.obj.process(fathersHash[id]);
			
			ugcTemplateComments.html = "";
			for(child_id in childsHash[id]) {
				if (childsHash[id][child_id]['id'])
					ugcTemplateComments.html += ugcTemplateComments.obj.process(childsHash[id][child_id]);
			}
			
			$jj("div[id="+ugcTemplatePlayer.targetId+"]").empty();
			$jj("div[id="+ugcTemplatePlayer.targetId+"]").append(ugcTemplatePlayer.html);
			$jj("div[id="+ugcTemplateInfo.targetId+"]").empty();
			$jj("div[id="+ugcTemplateInfo.targetId+"]").append(ugcTemplateInfo.html);
			$jj("div[id="+ugcTemplateComments.targetId+"]").empty();
			$jj("div[id="+ugcTemplateComments.targetId+"]").append(ugcTemplateComments.html);

		}
		else //stampa di tutto il commento in target
		{
			post_content = ugcTemplateDetailObj.process(fathersHash[id]);
	
			//alert(post_content);
			
			if (self['ugcTemplateComments']) {
				// stampa nel div indicato dal template ugcTemplateComments
				ugcTemplateComments.obj = TrimPath.parseTemplate(ugcTemplateComments.template);
				childs_content = "";				
				for(child_id in childsHash[id]) {
					if (childsHash[id][child_id]['id'])
						childs_content += ugcTemplateComments.obj.process(childsHash[id][child_id]);
				}				
				$jj("div[id="+ugcTemplateComments.targetId+"]").empty();	
				$jj("div[id="+ugcTemplateComments.targetId+"]").append(childs_content);	
			} else {
				// stampa di seguito al commento padre
				var child_index = 0;
				var child_length = 0;
				if(childsHash[id])
					child_length = childsHash[id].length;
				for(child_id in childsHash[id]) {
					child_index++;
					if (childsHash[id][child_id]['id']){
						if(child_index == child_length){
							childsHash[id][child_id]['last'] = 1;
						}else{
							childsHash[id][child_id]['last'] = 0;
						}
						childsHash[id][child_id]['oddEven'] = child_index%2;
						post_content += ugcTemplateDetailObj.process(childsHash[id][child_id]);
					}
				}				
			}
			
			if ($jj("div[id="+target+"]"))
				$jj("div[id="+target+"]").empty();
				$jj("div[id="+target+"]").append(post_content);
		}
	}
}


// stampa tutti i post
function printAllPosts(posts) {
	var posts_content = "";
	for (var i = 0; i < posts.length; i++) {
			//alert (posts[i]);
    	posts_content += printPost(posts[i],i%2);
	}
	if (document.getElementById("ugc_posts")) {
		document.getElementById("ugc_posts").innerHTML = posts_content;
	}
}

var fathersHash = new Object();
var childsHash = new Object();
// divide un vettore in post padri e post figli
function fathersAndChilds(posts){
	fathersHash = new Object();
	childsHash = new Object();
	childs = new Array(); 
	fathers = new Array(); 
	for (var i = 0; i < (posts.length); i++) {
	  if (posts[i]['idpadre']) {
  		var k = posts[i]['idpadre'];
  		if (!childsHash[k]) {
  			childsHash[k] = new Array();
  		}
			childs.push(posts[i]);			
			childsHash[k].push(posts[i]);
		}
		else {	
			fathers.push(posts[i]);
			fathersHash[posts[i].id] = posts[i];
		}
	}
	
/*
	for(var id in fathersHash) {
		if (childsHash[id])	{
			fathersHash[id]['numOfChilds'] = childsHash[id].length;
			//fathersHash[id]['childs'] = childsHash[id];
		}
		else {
			fathersHash[id]['numOfChilds'] = 0;
			//fathersHash[id]['childs'] = new Array();
		}
	}
*/	
	var d = "";
} 



// stampa tutti i post all interno di un intervallo di indice iniziale e ampiezza
function printPostsPage(posts,begin) {
  // DEBUG 	  	  alert ('608.Inizio record: '+begin);
	var posts_content = "";
	var end = begin + post4page;
	
	if (end > posts.length) {
		end = posts.length;
	}
	
	for (var i = begin; i < end; i++) {
  	id = posts[i]['id'];
		posts_content += printPost(posts[i],i%2);
	
		// stampa i figli
		if (self['showPost2Post']) {
			for(child_id in childsHash[id]) {
				if (childsHash[id][child_id]['id'])
					posts_content += printPost(childsHash[id][child_id]);
			}
		}

	}
	if (document.getElementById("ugc_posts")) {
		document.getElementById("ugc_posts").innerHTML = posts_content;
	}
	currentPage = (parseInt(begin/post4page))+1;
	// DEBUG 	  	  alert ('618.Pagina corrente: '+currentPage);
	numbersPages(fathers);
}

function addScript(scriptFile,id)
{
  var script=document.createElement('SCRIPT');
  script.id=id;
  script.src=scriptFile;
  var head=document.getElementsByTagName('HEAD')[0];
  head.appendChild(script);
}

// funzioni x la paginazione dei messaggi
// inserisce l elenco delle pagine nella paginazione
function numbersPages(posts) {
  	var tot = posts.length;
  	var res ='';
  	var testo ='';
  	
	if (post4page) {
	  	var num = parseInt(tot/post4page);
	  	if (tot%post4page) {
			num++;
		}
		if (!self['viewPagesText']) {
			viewPagesText = "%n%"; // stampa soltanto i numeri di pagina
		}

		if (num > 1)
		{
			var subs = (currentPage+2 > num) ? currentPage+2-num : 0 ;
			var minP = currentPage - 2 - subs;
			minP = (minP<1) ? 1 : minP;
			var additional = (minP == 1) ? 3-currentPage : 0 ;
			var maxP = currentPage + 2 + additional;
			maxP = (maxP>num) ? num : maxP;
						
			if (minP < currentPage) {
			  var be = post4page*(currentPage-2);
				res+="<a href=\"javascript:printPostsPage(fathers,"+be+")\">&laquo;indietro</a> ";
			}else{
				res+="&laquo;indietro&nbsp;&nbsp;";
			}
			
			for (var i=minP; i<=maxP; i++) {
				if (i == currentPage) {
					testo = viewPagesText.replace("%n%",i);
					testo = testo.replace("%t%",tot);
					res+="<span class=\"active\">"+(i<10 ? "&nbsp;" : "")+testo+(i<10 ? "&nbsp;" : "")+"</span> ";
				}
				else {
				  var be = post4page*(i-1);
					var en = (post4page*i)-1;
					testo = viewPagesText.replace("%n%",i);
					testo = testo.replace("%t%",tot);
					res+="<a href=\"javascript:printPostsPage(fathers,"+be+")\">"+(i<10 ? "&nbsp;" : "")+testo+(i<10 ? "&nbsp;" : "")+"</a> ";
				}
			}
			
			if (maxP > currentPage) {
			  var be = post4page*(currentPage);
				res+="<a href=\"javascript:printPostsPage(fathers,"+be+")\">avanti&raquo;</a> ";
			}else{
				res+="&nbsp;&nbsp;avanti&raquo;";
			}
			
		}

	}
	
	res = "<p>"+res+"</p><h4>Pagina "+currentPage+" di "+num+", totale messaggi: "+tot+"</h4>";
	
	if ($jj("div[id=forum_pagination]")) {
		$jj("div[id=forum_pagination]").empty();	//return res;
		$jj("div[id=forum_pagination]").append(res);	//return res;
	}
	if ($jj("div[id=forum_pagination2]")) {
		$jj("div[id=forum_pagination2]").empty();	//return res;
		$jj("div[id=forum_pagination2]").append(res);	//return res;
	}
	
}


function updateCmtList()
{
	if (self['cmtURL']) {	
		//startLoad();
		var dNow = new Date();
	  var script=document.getElementById("script_ugc_js");
	  if (script) {
	    script.parentNode.removeChild(script);
	  }
	  //addScript(cmtURL+"?"+dNow.getTime(),"script_ugc_js");
	  addScript(cmtURL,"script_ugc_js");
	} else if (self['posts']) {
		printAllPosts(posts);
	}
}

function updateSort(m)
{
	setSortMethod(m);
	printPosts(jsonPosts);
}

function onTagUpdateCmtList(tag) {
	cmtURL = "http://data.kataweb.it/ugc-mmservices/jstaglist/"+tag;
	//startLoad();
	var dNow = new Date();
  var script=document.getElementById("script_ugc_js");
  if (script) {
    script.parentNode.removeChild(script);
  }
  addScript(cmtURL+"?"+dNow.getTime(),"script_ugc_js");
}

function startLoad()
{
	$jj("div[id=ajaxLoadCommenti]").empty();
	$jj("div[id=ajaxLoadCommenti]").append("<img src='images/ajaxload.gif' border='0'>");
}

function stopLoad(request)
{
	$jj("div[id=ajaxLoadCommenti]").empty();
}

function printPost(post,oddEven) 
{
	post.oddEven=oddEven;
	if (ugcTemplateObj != null){
	  	return ugcTemplateObj.process(post);
	}
  return "";
}

function printPostAbstract(post,oddEven) 
{
	post.oddEven=oddEven;
	post.printAbstract = 1;
	if (ugcTemplateObj != null){
	  	return ugcTemplateObj.process(post);
	}
  return "";
}

//Finestre popup
function openwin(url, windowname, atrib, radio, channel) {
	window.open(url, windowname, atrib);
}

//Finestre popup
function openGetDetail(url, skin, idart, idcmt, windowname,atrib) {
	window.open(url+
		"?skin="+
		skin+"&idarticolo="+
		idart+"&idcommento="+
		idcmt, 
		windowname, atrib);
}


function showCommentDetail(detailPage,id)
{	
	if (detailPage.indexOf("target:")==0) {
		var targetId = detailPage.substr(detailPage.indexOf(":")+1);
		printPostDetail(targetId,id);
		return;
	}
	
	var toSend = new Array();	
	//toSend.push(0);
	var cmt = fathersHash[id];
	toSend.push(cmt);
	for (i in childsHash[id]) {
		toSend.push(childsHash[id][i]);
	}	
	
	var formName = "ugcDetail_"+id;
	var f = document.createElement('FORM');
	f.action = detailPage;
	f.target = "_self";
	f.method = "POST";
	f.id = formName;
	
	var data = document.createElement('INPUT');
	data.name = "data";
	data.value = encodeURI(toSend.toJSONString());
	data.type = "hidden";
	f.appendChild(data);

	var outid = document.createElement('INPUT');
	outid.name = "id";
	outid.value = id;
	outid.type = "hidden";
	f.appendChild(outid);

	document.getElementById("ugc_posts").appendChild(f);
	
	var f2 = document.forms[formName];
	f2.submit();
}

function showCommentPopDetail(detailPage,id)
{	
	var toSend = new Array();	
	var cmt = fathersHash[id];
	if (cmt) {
		toSend.push(cmt);
		for (i in childsHash[id]) {
			toSend.push(childsHash[id][i]);
		}	
	
		var formName = "ugcDetail_"+id;	
		var f = document.createElement('FORM');
		f.action = detailPage;
		f.target = "ugc_comment_datil";
		f.method = "POST";
		f.id = formName;
		
		var data = document.createElement('INPUT');
		data.name = "data";
		data.value = encodeURI(toSend.toJSONString());
		data.type = "hidden";
		f.appendChild(data);
	
		document.getElementById("ugc_posts").appendChild(f);
		
		var f2 = document.forms[formName];
	
		window.open("", "ugc_comment_datil", 'toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=no,width=728,height=600');
	
		f2.submit();
	}
}

var imageTarget = null;
var imageObj = null;
function showAttach(target,url,thumb,num,max)
{
	var obj = Object();
	obj['url'] = url;
	obj['thumb'] = thumb;
	obj['num'] = num;
	obj['max'] = max;
	imageObj = obj;
	imageTarget = target;

	if ($jj("div[id="+imageTarget+"]")) {
		var content = "";
		content = ugcTemplateAttach.process(imageObj);
		$jj("div[id="+target+"]").empty();
		$jj("div[id="+target+"]").append(content);
	}

}

/**
 * Costruisce la struttura del tag cloud
 * il template Javascript di riferimento 
 * templateTagCloud
 */
var ugcTagCloud = new Array();
ugcTagCloud["cloud"] = new Array();
var ugcTagCloudKeys = new Array();
function buildTagCloud(posts)
{
	ugcTagCloud = new Array();
	ugcTagCloud["cloud"] = new Array();
	ugcTagCloudKeys = new Array();
	// costruisce il tag cloud solo se presente il template
	if (self['templateTagCloud']) {
		for (var i = 0; i < (posts.length); i++) {
			var post_tags = posts[i].tags;
			for (var t = 0; t < (post_tags.length); t++) {
				if (post_tags[t]) {
					//clean tag				
					var tag = post_tags[t].replace(/^\s*(.*)\s*$/,'$1');
					
					if (typeof(ugcTagCloud.cloud[tag]) == "undefined") {
						ugcTagCloud.cloud[tag] = new Object();
						ugcTagCloud.cloud[tag]["count"] = 0;
						ugcTagCloud.cloud[tag]["posts"] = new Array();
						ugcTagCloudKeys.push(tag);
					}
					ugcTagCloud.cloud[tag].count++;
					try{
						ugcTagCloud.cloud[tag].posts.push(posts[i]);
					}catch(ex){
					};
				}
			}
		}
	}
	ugcTagCloudKeys.sort();
	//$('log').innerHTML = ugcTagCloudKeys.toJSONString();
	ugcTagCloud["tags"]=ugcTagCloudKeys;
	//$('log').innerHTML += ugcTagCloudKeys.length+"<br>";
	
	var max = 0;
	for (var t = 0; t < (ugcTagCloudKeys.length); t++) {
		if (ugcTagCloud.cloud[ugcTagCloudKeys[t]].count > max)
			max = ugcTagCloud.cloud[ugcTagCloudKeys[t]].count;
	}
	for (var t = 0; t < (ugcTagCloudKeys.length); t++) {
		var c = ugcTagCloud.cloud[ugcTagCloudKeys[t]].count;
		ugcTagCloud.cloud[ugcTagCloudKeys[t]]["size"] = Math.round((c/max)*5);
	}
}

function printPostsTagged(tag) {
		
	if (tag == undefined) {
		printPosts(jsonPosts);		
	} else {

		try {
			toPrint = ugcTagCloud.cloud[tag].posts;	
			if (toPrint != undefined) {
				document.getElementById("ugc_posts").innerHTML = "Caricamento in corso..."
				$jj("div[id=forum_pagination]").empty();
				$jj("div[id=forum_pagination]").append("Tag: <strong>"+tag+"</strong>");
				$jj("div[id=forum_pagination2]").empty();
				
				toPrint.sort(sortMethod);
				printAllPosts(toPrint);
			}
		} catch (e) {}
	}
}

function displayPerTag(){
	document.getElementById("ugc_posts").innerHTML = "";
	$jj("div[id=forum_pagination]").empty();
	$jj("div[id=forum_pagination2]").empty();
	if (templateTagCloudObj && ugcTagCloud.tags.length>0) {
		$jj("div[id=ugc_tagcloud]").empty();
		$jj("div[id=ugc_tagcloud]").append(templateTagCloudObj.process(ugcTagCloud));
	}
}

var ugcTemplateObj = null;
var ugcTemplateDetailObj = null;
var ugcTemplateAttach = null;
var templateTagCloudObj = null;

function initCommenti()
{
	if (self['ugc_container'] && (controllaEspanso() || self['ugcTemplateDetail'])){
		document.write(ugc_container);
	}else{
		document.write(ugc_abs_container);
		if(postAbstractToDisplay == 0){
			printPosts(new Array());
		}
	}
	
	if (self['defaultSortMethod']){
		setSortMethod(defaultSortMethod);
	}else{
		setSortMethod("date");
	}
	
	if (self['ugcTemplate']){
		try {
			ugcTemplateObj = TrimPath.parseTemplate(ugcTemplate);
		} catch (e) {
			ugcTemplateObj = null;
		}
	}else{ 
		ugcTemplateObj = null;
	}
	
	if (self['ugcTemplateDetail']){
		try {
			ugcTemplateDetailObj = TrimPath.parseTemplate(ugcTemplateDetail);
		} catch (e) {
			ugcTemplateDetailObj = null;
		}
	}else{
		ugcTemplateDetailObj = null;
	}
	
	if (self['attachTemplate']){
		try {
			ugcTemplateAttach = TrimPath.parseTemplate(attachTemplate);
		} catch (e) {
			ugcTemplateAttach = null;
		}
	}else{
		ugcTemplateAttach = null;
	}

	if (self['templateTagCloud']){
		try {
			templateTagCloudObj = TrimPath.parseTemplate(templateTagCloud);
		} catch (e) {
			templateTagCloudObj = null;
		}	
	}else{
		templateTagCloudObj = null;
	}

	updateCmtList();
}

var templateScriptRoot = scriptRoot;

initCommenti();
